"""
when user type the command: python manageMongo.py makemigrations [app_name]:
    - generate a file from mongoModels.py into migrationMongo folder

when user type the command: python manageMongo.py migrate [app_name]:
    - connect to mongodb and execute files migrationMongo folder 
"""
